@@ -3,17 +3,21 @@ $parameters = array(
 	'db_driver' => 'mysqli',
 	'db_host_ro' => null,
 	'db_table_prefix' => null,
-    'db_host' => 'localhost',
-    'db_port' => '3306',
-    'db_name' => 'mauticdemodb',
-    'db_user' => 'mauticdemo',
-    'db_password' => 'cgtNcvMuNA95xt5h',
+	'db_host' => 'localhost',
+	'db_port' => '3306',
+	'db_name' => 'mauticdemodb',
+	'db_user' => 'mauticdemo',
+	'db_password' => 'cgtNcvMuNA95xt5h',
 	'db_backup_tables' => 1,
 	'db_backup_prefix' => 'bak_',
 	'secret_key' => 'b9264e8291f71431807ec079d5027d24e1a7c0bfaefa38359a6cea0eb359eca1',
-    'site_url' => 'https://demo.cause.buzz',
-    'trusted_hosts' => ['demo.cause.buzz'],
-    'trusted_proxies' => ['172.17.0.1'],
+	'site_url' => 'https://demo.cause.buzz',
+	'trusted_hosts' => array(
+		'0' => 'demo.cause.buzz'
+	),
+	'trusted_proxies' => array(
+		'0' => '172.17.0.1'
+	),
 	'api_enabled' => 1,
 	'api_enable_basic_auth' => false,
 	'api_oauth2_access_token_lifetime' => 60,
@@ -65,7 +69,7 @@ $parameters = array(
 	'campaign_use_summary' => 0,
 	'campaign_by_range' => 0,
 	'delete_campaign_event_log_in_background' => false,
-	'webroot' => 4,
+	'webroot' => null,
 	'404_page' => null,
 	'cache_path' => '/var/www/html/mauticGIT-Test/var/cache',
 	'log_path' => '/var/www/html/mauticGIT-Test/var/logs',
@@ -504,7 +508,8 @@ $parameters = array(
 	'transliterate_page_title' => 0,
 	'cors_restrict_domains' => 1,
 	'cors_valid_domains' => array(
-
+		'0' => 'https://cause.buzz',
+		'1' => 'https://*.figma.site'
 	),
 	'headers_sts' => 0,
 	'headers_sts_expire_time' => 60,
@@ -640,48 +645,6 @@ $parameters = array(
 	'webview_text' => '<a href="|URL|">Having trouble reading this email? Click here.</a>',
 	'unsubscribe_message' => 'Es tut uns leid, Sie gehen zu sehen! |EMAIL| erhalten keine E-Mails mehr von uns. Wenn dies ein Fehler war, <a href="|URL|">klicken Sie hier, um sich erneut anzumelden</a>.',
 	'resubscribe_message' => '|EMAIL| wurde erneut abonniert. Wenn dies ein Fehler war, <a href="|URL|">klicken Sie hier, um sich abzumelden</a>.',
-// Cause buzz to provide details if this is needed at all
-//	'monitored_email' => array(
-//		'general' => array(
-//			'address' => 'info@fpoe-ktn.at',
-//			'host' => 'xmail.xpirio.net',
-//			'port' => '993',
-//			'encryption' => '/ssl',
-//			'user' => 'info@fpoe-ktn.at',
-//			'password' => 'some981MAGIC',
-//			'use_attachments' => ''
-//		),
-//		'EmailBundle_bounces' => array(
-//			'address' => '',
-//			'host' => '',
-//			'port' => '993',
-//			'encryption' => '/ssl',
-//			'user' => '',
-//			'password' => '',
-//			'override_settings' => '0',
-//			'folder' => 'INBOX'
-//		),
-//		'EmailBundle_unsubscribes' => array(
-//			'address' => '',
-//			'host' => '',
-//			'port' => '993',
-//			'encryption' => '/ssl',
-//			'user' => '',
-//			'password' => '',
-//			'override_settings' => '0',
-//			'folder' => ''
-//		),
-//		'EmailBundle_replies' => array(
-//			'address' => '',
-//			'host' => '',
-//			'port' => '993',
-//			'encryption' => '/ssl',
-//			'user' => '',
-//			'password' => '',
-//			'override_settings' => '0',
-//			'folder' => ''
-//		)
-//	),
 	'mailer_is_owner' => 0,
 	'default_signature_text' => 'Best regards, |FROM_NAME|',
 	'email_frequency_number' => 0,
@@ -711,19 +674,12 @@ $parameters = array(
 	'contact_api_count_cache_ttl' => 5,
 	'contact_columns' => array(
 		'0' => 'id',
-		'1' => 'salutation',
-		'2' => 'title',
-		'3' => 'name',
-		'4' => 'email',
-		'5' => 'zipcode',
-		'6' => 'stadt',
-		'7' => 'optinstatus',
-		'8' => 'last_active',
-		'9' => 'email_ja',
-		'10' => 'sms_ja',
-		'11' => 'post_ja',
-		'12' => 'info_mail_ja',
-		'13' => 'info_mail_bund_ja'
+		'1' => 'title',
+		'2' => 'name',
+		'3' => 'email',
+		'4' => 'zipcode',
+		'5' => 'stadt',
+		'6' => 'last_active'
 	),
 	'create_custom_field_in_background' => false,
 	'contact_unique_identifiers_operator' => 'OR',
@@ -831,4 +787,46 @@ $parameters = array(
 	'peak_interaction_timer_max_optimal_days' => 3,
 	'mailer_address_length_limit' => 320,
 	'email_draft_enabled' => 0,
+	'monitored_email' => array(
+		'general' => array(
+			'address' => '',
+			'host' => '',
+			'port' => '993',
+			'encryption' => '/ssl',
+			'user' => '',
+			'password' => '',
+			'use_attachments' => ''
+		),
+		'EmailBundle_bounces' => array(
+			'address' => '',
+			'host' => '',
+			'port' => '993',
+			'encryption' => '/ssl',
+			'user' => '',
+			'password' => '',
+			'override_settings' => '0',
+			'folder' => ''
+		),
+		'EmailBundle_unsubscribes' => array(
+			'address' => '',
+			'host' => '',
+			'port' => '993',
+			'encryption' => '/ssl',
+			'user' => '',
+			'password' => '',
+			'override_settings' => '0',
+			'folder' => ''
+		),
+		'EmailBundle_replies' => array(
+			'address' => '',
+			'host' => '',
+			'port' => '993',
+			'encryption' => '/ssl',
+			'user' => '',
+			'password' => '',
+			'override_settings' => '0',
+			'folder' => ''
+		)
+	),
+	'saml_idp_entity_id' => 'https://demo.cause.buzz',
 );
